@@ -1,33 +1,31 @@
+from typing import NamedTuple
+
 import copy
 import math
 import numpy as np
 import time
 
-from collections import namedtuple
 from ama_xiv_combat_sim.simulator.calcs.compute_damage_utils import ComputeDamageUtils
+from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.trackers.damage_tracker import DamageTracker
+from ama_xiv_combat_sim.simulator.trackers.offensive_status_effects import OffensiveStatusEffects
 
+class StatusEffectsTuple(NamedTuple):
+    buffs: OffensiveStatusEffects
+    debuffs: OffensiveStatusEffects
 
-class PerInstanceDamage(
-    namedtuple(
-        "PerInstanceDamage",
-        [
-            "application_time",
-            "snapshot_time",
-            "skill_name",
-            "potency",
-            "skill_modifier_condition",
-            "status_effects",
-            "expected_damage",
-            "standard_deviation",
-            "event_id",
-            "target",
-            "damage_class",
-        ],
-    )
-):
-    pass
-
+class PerInstanceDamage(NamedTuple):
+    application_time: np.float64
+    snapshot_time: np.float64
+    skill_name: str
+    potency: np.float64
+    skill_modifier_condition: set[str]
+    status_effects: StatusEffectsTuple
+    expected_damage: np.float64
+    standard_deviation: np.float64
+    event_id: int
+    target: str
+    damage_class: DamageClass
 
 class DamageSimulator:
     def __init__(
@@ -71,6 +69,7 @@ class DamageSimulator:
             damage_mult = ComputeDamageUtils.compute_damage_mult(status_effects)
 
             damage_spec = skill.get_damage_spec(skill_modifier)
+            single_damage_mult = damage_spec.single_damage_mult #things like AF/UI
             damage_class = damage_spec.damage_class
             trait_damage_mult = (
                 self.__stats.processed_stats.trait_damage_mult
@@ -84,17 +83,18 @@ class DamageSimulator:
                 crit_bonus,
                 dh_rate,
                 trait_damage_mult,
+                single_damage_mult,
                 damage_mult,
                 t,
                 damage_spec.potency,
                 skill_modifier,
-                (status_effects[0], status_effects[1]),
+                StatusEffectsTuple(buffs=status_effects[0], debuffs=status_effects[1]),
                 damage_class,
             )
             self.__target[i] = target
             i += 1
 
-        self.__damage_tracker.finalize()        
+        self.__damage_tracker.finalize()
 
         if len(self.__dmg_instances) == 0:
             fight_time = 0
