@@ -1,7 +1,11 @@
 import math
 
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.game_data.game_consts import GameConsts
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
@@ -9,13 +13,23 @@ from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
 from ama_xiv_combat_sim.simulator.specs.job_resource_spec import JobResourceSpec
 from ama_xiv_combat_sim.simulator.specs.job_resource_settings import JobResourceSettings
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.caster.blm_data import (
     all_blm_skills,
 )
 
+# TODO(ama): enochian should be granted immediately, not on damage application.
+# this is important to properly grant enochian timings, especially to opening damage.
+# This is important for skills with long damage application times.
+
 
 class BlmSkills(GenericJobClass):
 
@@ -96,8 +110,7 @@ class BlmSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     damage_mult=self._skill_data.get_skill_data(name, "damage_mult"),
                     duration=self._skill_data.get_skill_data(name, "duration"),
                 ),
@@ -121,7 +134,7 @@ class BlmSkills(GenericJobClass):
         name = "Umbral Ice"
         job_resource_settings = JobResourceSettings(
             max_value=3,
-            expiry_from_last_gain=15 * 1000,
+            expiry_from_last_gain=self._skill_data.get_skill_data(name, "duration"),
             skill_allowlist=self.__ui_skill_allowlist,
         )
         return (name, job_resource_settings)
@@ -235,6 +248,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -247,7 +261,6 @@ class BlmSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency("Thunder III (dot)"),
                     damage_class=DamageClass.MAGICAL_DOT,
@@ -267,7 +280,6 @@ class BlmSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency("Thunder IV (dot)"),
                     damage_class=DamageClass.MAGICAL_DOT,
@@ -288,6 +300,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=False
             ),
@@ -350,8 +363,7 @@ class BlmSkills(GenericJobClass):
         name = "Firestarter"
         firestarter_buff = Skill(
             name=name,
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=self._skill_data.get_skill_data(name, "duration"),
@@ -367,10 +379,11 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=0, application_delay=0
             ),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=30 * 1000,
@@ -384,8 +397,7 @@ class BlmSkills(GenericJobClass):
         name = "Thundercloud"
         thundercloud_buff = Skill(
             name=name,
-            is_GCD=False,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=40 * 1000,
@@ -403,10 +415,11 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=0, application_delay=0
             ),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=40 * 1000,
@@ -422,8 +435,7 @@ class BlmSkills(GenericJobClass):
             else FollowUp(
                 skill=Skill(
                     name="Enhanced",
-                    is_GCD=False,
-                    buff_spec=StatusEffectSpec(
+                    offensive_buff_spec=OffensiveStatusEffectSpec(
                         add_to_skill_modifier_condition=True,
                         num_uses=1,
                         # this is incorrect, since it expires with astral fire.
@@ -438,6 +450,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=True
             ),
@@ -487,6 +500,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=fire_damage_spec,
             timing_spec=fire_timing_spec,
             job_resource_spec=fire_job_resource_spec,
@@ -515,6 +529,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=(
                 {
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -549,7 +564,7 @@ class BlmSkills(GenericJobClass):
         fire_iii_timing_spec = self.__get_enochian_timing_spec_cross(
             base_cast_time=self._skill_data.get_skill_data(name, "cast_time"),
             is_fire_spell=True,
-            application_delay=1290,
+            application_delay=0,
         )
         fire_iii_keys = tuple(fire_iii_damage_spec.keys())
         for k in fire_iii_keys:
@@ -562,13 +577,23 @@ class BlmSkills(GenericJobClass):
             fire_iii_timing_spec[assembled_str] = TimingSpec(
                 base_cast_time=0,
                 animation_lock=self.__base_animation_lock,
-                application_delay=1290,
+                application_delay=0,
+            )
+
+        fire_iii_followups = {}
+        for k, val in fire_iii_damage_spec.items():
+            fire_iii_followups[k] = (
+                FollowUp(
+                    skill=Skill(name="Fire III", damage_spec=val),
+                    delay_after_parent_application=1290,
+                ),
+                self.__enochian_buff_follow_up,
             )
 
         return Skill(
             name=name,
             is_GCD=True,
-            damage_spec=fire_iii_damage_spec,
+            skill_type=SkillType.SPELL,
             timing_spec=fire_iii_timing_spec,
             job_resource_spec=(
                 self.__clear_umbral_ice,
@@ -578,7 +603,7 @@ class BlmSkills(GenericJobClass):
                     refreshes_duration_of_last_gained=True,
                 ),
             ),
-            follow_up_skills=(self.__enochian_buff_follow_up,),
+            follow_up_skills=fire_iii_followups,
         )
 
     @GenericJobClass.is_a_skill
@@ -587,6 +612,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=False
             ),
@@ -595,7 +621,9 @@ class BlmSkills(GenericJobClass):
                 is_fire_spell=False,
                 application_delay=840,
             ),
-            buff_spec=StatusEffectSpec(expires_status_effects=("Enhanced",)),
+            offensive_buff_spec=OffensiveStatusEffectSpec(
+                expires_status_effects=("Enhanced",)
+            ),
             job_resource_spec=(
                 self.__clear_astral_fire,
                 JobResourceSpec(
@@ -611,6 +639,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=False
             ),
@@ -632,6 +661,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=(
                 DamageSpec(potency=self._skill_data.get_potency(name))
                 if self._version >= "7.0"
@@ -730,6 +760,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=flare_damage_spec,
             timing_spec=flare_timing_spec,
             job_resource_spec=(
@@ -751,8 +782,9 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 haste_time_reduction=0.15,
                 auto_attack_delay_reduction=0.15,
                 duration=self._skill_data.get_skill_data(name, "duration"),
@@ -765,6 +797,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=False
             ),
@@ -781,6 +814,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=True
             ),
@@ -799,6 +833,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=(
                 DamageSpec(potency=self._skill_data.get_potency(name))
                 if self._version >= "7.0"
@@ -857,6 +892,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -873,6 +909,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=True
             ),
@@ -899,6 +936,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0,
@@ -913,13 +951,16 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=self.__get_enochian_damage_spec_cross(
                 base_potency=self._skill_data.get_potency(name), is_fire_spell=False
             ),
             timing_spec=self.__get_enochian_timing_spec_cross(
                 base_cast_time=3000, is_fire_spell=False, application_delay=1160
             ),
-            buff_spec=StatusEffectSpec(expires_status_effects=("Enhanced",)),
+            offensive_buff_spec=OffensiveStatusEffectSpec(
+                expires_status_effects=("Enhanced",)
+            ),
             job_resource_spec=(
                 self.__clear_astral_fire,
                 JobResourceSpec(
@@ -990,6 +1031,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=(
                 {
@@ -1067,7 +1109,6 @@ class BlmSkills(GenericJobClass):
         high_thunder_follow_up = FollowUp(
             skill=Skill(
                 name="Thunder (dot)",
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency("High Thunder (dot)"),
                     damage_class=DamageClass.MAGICAL_DOT,
@@ -1085,6 +1126,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
@@ -1101,7 +1143,6 @@ class BlmSkills(GenericJobClass):
         high_thunder_ii_follow_up = FollowUp(
             skill=Skill(
                 name="Thunder (dot)",
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency("High Thunder II (dot)"),
                     damage_class=DamageClass.MAGICAL_DOT,
@@ -1119,6 +1160,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
@@ -1145,6 +1187,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec=flare_star_damage_spec,
             timing_spec=flare_star_timing_spec,
             has_aoe=True,
@@ -1157,8 +1200,9 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 flat_cast_time_reduction=math.inf,
                 duration=10 * 1000,
                 num_uses=1,
@@ -1207,8 +1251,9 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 flat_cast_time_reduction=math.inf,
                 duration=10 * 1000,
                 num_uses=3,
@@ -1257,19 +1302,20 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
-            buff_spec=(
+            offensive_buff_spec=(
                 None
                 if self._version >= "7.0"
                 else {
                     SimConsts.DEFAULT_CONDITION: None,
-                    "1 Umbral Ice": StatusEffectSpec(
+                    "1 Umbral Ice": OffensiveStatusEffectSpec(
                         expires_status_effects=("Enhanced",)
                     ),
-                    "2 Umbral Ice": StatusEffectSpec(
+                    "2 Umbral Ice": OffensiveStatusEffectSpec(
                         expires_status_effects=("Enhanced",)
                     ),
-                    "3 Umbral Ice": StatusEffectSpec(
+                    "3 Umbral Ice": OffensiveStatusEffectSpec(
                         expires_status_effects=("Enhanced",)
                     ),
                 }
@@ -1336,8 +1382,9 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=1,
                 duration=30 * 1000,
@@ -1351,6 +1398,39 @@ class BlmSkills(GenericJobClass):
             ),
         )
 
+    @GenericJobClass.is_a_skill
+    def manaward(self):
+        name = "Manaward"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec=ShieldSpec(
+                shield_on_max_hp=0.3, duration=20 * 1000, is_party_effect=False
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def addle(self):
+        name = "Addle"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=(
+                    {
+                        DamageInstanceClass.PHYSICAL: 0.05,
+                        DamageInstanceClass.MAGICAL: 0.1,
+                    }
+                ),
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
@@ -1361,6 +1441,7 @@ class BlmSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.__blm_instant_timing_spec,
             job_resource_spec=(
                 (
@@ -1380,12 +1461,25 @@ class BlmSkills(GenericJobClass):
     def umbral_soul(self):
         name = "Umbral Soul"
         return Skill(
-            name=name, is_GCD=False, timing_spec=self.__blm_instant_timing_spec
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.__blm_instant_timing_spec,
+            job_resource_spec=(
+                JobResourceSpec(
+                    name="Umbral Ice",
+                    change=+1,
+                    refreshes_duration_of_last_gained=True,
+                ),
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def amplifier(self):
         name = "Amplifier"
         return Skill(
-            name=name, is_GCD=False, timing_spec=self.__blm_instant_timing_spec
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.__blm_instant_timing_spec,
         )
