@@ -72,16 +72,18 @@ ALL_DATA = {
     },
     "Scathe": {90: {"potency": {"6.55": 100}}, 100: {"potency": {"7.0": 100}}},
     "Fire III": {
-        90: {"potency": {"6.55": 260, "7.0": 280, "7.2": 290},
-             "cast_time": {"6.55": 3500}},
-        100: {"potency": {"7.0": 280, "7.2": 290},
-              "cast_time": {"7.0": 3500}},
+        90: {
+            "potency": {"6.55": 260, "7.0": 280, "7.2": 290},
+            "cast_time": {"6.55": 3500},
+        },
+        100: {"potency": {"7.0": 280, "7.2": 290}, "cast_time": {"7.0": 3500}},
     },
     "Blizzard III": {
-        90: {"potency": {"6.55": 260, "7.0": 280, "7.2": 290},
-             "cast_time": {"6.55": 3500}},
-        100: {"potency": {"7.0": 280, "7.2": 290},
-              "cast_time": {"7.0": 3500}},
+        90: {
+            "potency": {"6.55": 260, "7.0": 280, "7.2": 290},
+            "cast_time": {"6.55": 3500},
+        },
+        100: {"potency": {"7.0": 280, "7.2": 290}, "cast_time": {"7.0": 3500}},
     },
     "Freeze": {
         90: {"potency": {"6.55": 120}, "cast_time": {"6.55": 2800, "7.2": 2000}},
@@ -112,7 +114,7 @@ ALL_DATA = {
     },
     "Fire IV": {
         90: {
-            "potency": {"6.55": 310, "7.05": 320},
+            "potency": {"6.55": 310, "7.05": 320, "7.2": 300},
             "cast_time": {"6.55": 2800, "7.2": 2000},
         },
         100: {
@@ -131,13 +133,19 @@ ALL_DATA = {
         },
     },
     "Despair": {
-        90: {"potency": {"6.55": 340, "7.05": 350}, "cast_time": {"6.55": 3000, "7.2": 2000}},
+        90: {
+            "potency": {"6.55": 340, "7.05": 350},
+            "cast_time": {"6.55": 3000, "7.2": 2000},
+        },
         100: {
             "potency": {"7.0": 340, "7.05": 350},
             "cast_time": {"7.0": 3000, "7.1": 0},
         },
     },
-    "Xenoglossy": {90: {"potency": {"6.55": 880}}, 100: {"potency": {"7.0": 880, "7.2": 890}}},
+    "Xenoglossy": {
+        90: {"potency": {"6.55": 880, "7.2": 890}},
+        100: {"potency": {"7.0": 880, "7.2": 890}},
+    },
     "High Fire II": {
         90: {"potency": {"6.55": 140, "7.0": 100}},
         100: {"potency": {"7.0": 100}},
@@ -152,8 +160,12 @@ ALL_DATA = {
     },
     "High Thunder": {100: {"potency": {"7.0": 200, "7.05": 150}}},
     "High Thunder II": {100: {"potency": {"7.0": 100}}},
-    "Flare Star": {100: {"potency": {"7.0": 400, "7.2": 500}, 
-                         "cast_time": {"7.0": 3000, "7.2": 2000},}},
+    "Flare Star": {
+        100: {
+            "potency": {"7.0": 400, "7.2": 500},
+            "cast_time": {"7.0": 3000, "7.2": 2000},
+        }
+    },
     "Firestarter": {
         90: {
             "allowlist": {"6.55": ("Fire",)},
@@ -222,8 +234,10 @@ ALL_DATA = {
                     "High Fire II",
                     "High Blizzard II",
                     "Paradox",
+                    "Umbral Soul",
                 )
-            }
+            },
+            "duration": {"6.55": 15 * 1000, "7.2": float("inf")},
         },
         100: {
             "allowlist": {
@@ -242,8 +256,10 @@ ALL_DATA = {
                     "Paradox",
                     "Manafont",
                     "Flare Star",
+                    "Umbral Soul",
                 )
-            }
+            },
+            "duration": {"7.0": 15 * 1000, "7.2": float("inf")},
         },
     },
 }
