@@ -11,7 +11,10 @@ ALL_DATA = {
     "Energy Siphon": {90: {"potency": {"6.55": 100}}, 100: {"potency": {"7.0": 100}}},
     "Ruin III": {
         90: {"potency": {"6.55": 310}, "potency_aethercharge": {"6.55": 360}},
-        100: {"potency": {"7.0": 360}, "potency_aethercharge": {"7.0": 410}},
+        100: {
+            "potency": {"7.0": 360, "7.3": 400},
+            "potency_aethercharge": {"7.0": 410, "7.3": 450},
+        },
     },
     "Astral Impulse": {90: {"potency": {"6.55": 440}}, 100: {"potency": {"7.0": 500}}},
     "Astral Flare": {90: {"potency": {"6.55": 180}}, 100: {"potency": {"7.0": 180}}},
@@ -25,7 +28,10 @@ ALL_DATA = {
             "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5},
         },
     },
-    "Ruin IV": {90: {"potency": {"6.55": 430}}, 100: {"potency": {"7.0": 490}}},
+    "Ruin IV": {
+        90: {"potency": {"6.55": 430}},
+        100: {"potency": {"7.0": 490, "7.3": 520}},
+    },
     "Searing Light": {
         90: {
             "damage_mult": {"6.55": 1.03, "7.0": 1.05},
@@ -43,9 +49,15 @@ ALL_DATA = {
             "aoe_dropoff": {"7.0": 0.6, "7.25": 0.5},
         },
     },
-    "Ruby Rite": {90: {"potency": {"6.55": 510}}, 100: {"potency": {"7.0": 540}}},
+    "Ruby Rite": {
+        90: {"potency": {"6.55": 510}},
+        100: {"potency": {"7.0": 540, "7.3": 580}},
+    },
     "Topaz Rite": {90: {"potency": {"6.55": 330}}, 100: {"potency": {"7.0": 340}}},
-    "Emerald Rite": {90: {"potency": {"6.55": 230}}, 100: {"potency": {"7.0": 240}}},
+    "Emerald Rite": {
+        90: {"potency": {"6.55": 230}},
+        100: {"potency": {"7.0": 240, "7.3": 280}},
+    },
     "Tri-disaster": {90: {"potency": {"6.55": 120}}, 100: {"potency": {"7.0": 120}}},
     "Fountain of Fire": {
         90: {"potency": {"6.55": 540}},
@@ -71,22 +83,58 @@ ALL_DATA = {
         90: {"potency": {"6.55": 100}},
         100: {"potency": {"7.0": 100}},
     },
-    "Crimson Cyclone": {90: {"potency": {"6.55": 430}}, 100: {"potency": {"7.0": 490}}},
-    "Crimson Strike": {90: {"potency": {"6.55": 430}}, 100: {"potency": {"7.0": 490}}},
-    "Mountain Buster": {90: {"potency": {"6.55": 150}}, 100: {"potency": {"7.0": 160}}},
+    "Crimson Cyclone": {
+        90: {"potency": {"6.55": 430}, "aoe_dropoff": {"6.55": 0.65, "7.3": 0.6}},
+        100: {
+            "potency": {"7.0": 490, "7.3": 520},
+            "aoe_dropoff": {"7.0": 0.65, "7.3": 0.6},
+        },
+    },
+    "Crimson Strike": {
+        90: {"potency": {"6.55": 430}, "aoe_dropoff": {"6.55": 0.65, "7.3": 0.6}},
+        100: {
+            "potency": {"7.0": 490, "7.3": 520},
+            "aoe_dropoff": {"7.0": 0.65, "7.3": 0.6},
+        },
+    },
+    "Mountain Buster": {
+        90: {
+            "potency": {"6.55": 150},
+            "aoe_dropoff": {"6.55": 0.7, "7.3": 0.6},
+        },
+        100: {
+            "potency": {"7.0": 160},
+            "aoe_dropoff": {"7.0": 0.7, "7.3": 0.6},
+        },
+    },
     "Slipstream (dot)": {90: {"potency": {"6.55": 30}}, 100: {"potency": {"7.0": 30}}},
-    "Slipstream": {90: {"potency": {"6.55": 430}}, 100: {"potency": {"7.0": 490}}},
+    "Slipstream": {
+        90: {"potency": {"6.55": 430}, "aoe_dropoff": {"6.55": 0.65, "7.3": 0.6}},
+        100: {
+            "potency": {"7.0": 490, "7.3": 520},
+            "aoe_dropoff": {"7.0": 0.65, "7.3": 0.6},
+        },
+    },
     "Inferno (pet)": {
-        90: {"potency": {"6.55": 750}},
-        100: {"potency": {"7.0": 750, "7.1": 800}},
+        90: {"potency": {"6.55": 750}, "aoe_dropoff": {"6.55": 0.6, "7.3": 0.5}},
+        100: {
+            "potency": {"7.0": 750, "7.1": 800},
+            "aoe_dropoff": {"7.0": 0.6, "7.3": 0.5},
+        },
     },
     "Earthen Fury (pet)": {
-        90: {"potency": {"6.55": 750}},
-        100: {"potency": {"7.0": 750, "7.1": 800}},
+        90: {"potency": {"6.55": 750}, "aoe_dropoff": {"6.55": 0.6, "7.3": 0.5}},
+        100: {
+            "potency": {"7.0": 750, "7.1": 800},
+            "aoe_dropoff": {"7.0": 0.6, "7.3": 0.5},
+        },
     },
     "Aerial Blast (pet)": {
-        90: {"potency": {"6.55": 750}},
-        100: {"potency": {"7.0": 750, "7.1": 800}},
+        90: {"potency": {"6.55": 750}, "aoe_dropoff": {"6.55": 0.6, "7.3": 0.5}},
+        100: {
+            "potency": {"7.0": 750, "7.1": 800},
+            "aoe_dropoff": {"7.0": 0.6, "7.3": 0.5},
+        },
     },
     "Scarlet Flame (pet)": {
         90: {"potency": {"6.55": 150}},
