@@ -1,12 +1,22 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.melee.drg_data import (
@@ -43,8 +53,9 @@ class DrgSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(damage_mult=1.10, duration=int(31.6 * 1000)),
+                offensive_buff_spec=OffensiveStatusEffectSpec(
+                    damage_mult=1.10, duration=int(31.6 * 1000)
+                ),
             ),
             delay_after_parent_application=0,
         )
@@ -55,6 +66,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -67,6 +79,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -82,6 +95,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("True Thrust", "Raiden Thrust")),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -102,6 +116,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=(
                 {
                     SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -145,6 +160,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("True Thrust", "Raiden Thrust")),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=0
@@ -164,10 +180,11 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=660
             ),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 damage_mult=self._skill_data.get_skill_data(name, "damage_mult"),
                 duration=self._skill_data.get_skill_data(name, "duration"),
             ),
@@ -179,6 +196,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -195,6 +213,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=800, application_delay=800
@@ -207,6 +226,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=800, application_delay=800
@@ -221,10 +241,11 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=625
             ),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 crit_rate_add=self._skill_data.get_skill_data(name, "crit_rate_add"),
                 duration=self._skill_data.get_skill_data(name, "duration"),
                 is_party_effect=True,
@@ -237,6 +258,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(
                 (ComboSpec(combo_actions=("Heavens' Thrust",)),)
                 if self._version >= "7.0"
@@ -282,13 +304,13 @@ class DrgSkills(GenericJobClass):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=620
             ),
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
-                    duration=30
-                    * 1000,  # is this actually 31.6? or 30+application delay or whatever?
+                    # is this actually 31.6? or 30+application delay or whatever?
                     # have this buff be consumed (and maybe wasted) on next weaponskill
+                    duration=30 * 1000,
                     skill_allowlist=self.__drg_weapon_skills,
                 ),
                 "Wheeling Thrust": None,
@@ -301,6 +323,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(
                 (ComboSpec(combo_actions=("Chaotic Spring",)),)
                 if self._version >= "7.0"
@@ -344,8 +367,8 @@ class DrgSkills(GenericJobClass):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=620
             ),
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=30
@@ -363,7 +386,9 @@ class DrgSkills(GenericJobClass):
             life_of_the_dragon_follow_up = FollowUp(
                 skill=Skill(
                     name="Life of the Dragon",
-                    buff_spec=StatusEffectSpec(damage_mult=1.15, duration=20 * 1000),
+                    offensive_buff_spec=OffensiveStatusEffectSpec(
+                        damage_mult=1.15, duration=20 * 1000
+                    ),
                 ),
                 delay_after_parent_application=0,
             )
@@ -379,9 +404,13 @@ class DrgSkills(GenericJobClass):
                 snapshot_debuffs_with_parent=True,
                 primary_target_only=False,
             )
+        else:
+            life_of_the_dragon_follow_up = None
+            geirskogul_damage_follow_up = None
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=(
                 None
                 if self._version >= "7.0"
@@ -432,6 +461,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Doom Spike",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=0
@@ -454,6 +484,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Wheeling Thrust", "Fang and Claw")),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -469,17 +500,18 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=0, animation_lock=600, application_delay=660
                 ),
                 "Left Eye": TimingSpec(base_cast_time=0, animation_lock=0),
             },
-            buff_spec={
-                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+            offensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: OffensiveStatusEffectSpec(
                     damage_mult=1.1, duration=20 * 1000
                 ),
-                "Left Eye": StatusEffectSpec(
+                "Left Eye": OffensiveStatusEffectSpec(
                     damage_mult=1.05, duration=20 * 1000, is_party_effect=True
                 ),
             },
@@ -494,8 +526,9 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(base_cast_time=0, animation_lock=0),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 damage_mult=1.05, duration=20 * 1000, is_party_effect=True
             ),
         )
@@ -506,6 +539,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=800
@@ -518,13 +552,14 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             # damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=self._skill_data.get_potency(name))},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=760
             ),
             has_aoe=True,
-            aoe_dropoff=self._skill_data.get_skill_data(name, 'aoe_dropoff')
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -533,6 +568,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Sonic Thrust",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -554,6 +590,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=800, application_delay=490
@@ -566,6 +603,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -579,12 +617,13 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=1500, application_delay=1290
             ),
             has_aoe=True,
-            aoe_dropoff=0.5,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -593,6 +632,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=760
@@ -606,6 +646,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(
                 ComboSpec(
                     combo_actions=self._skill_data.get_skill_data(name, "combo_action")
@@ -630,7 +671,6 @@ class DrgSkills(GenericJobClass):
         _chaotic_spring_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.PHYSICAL_DOT,
@@ -646,6 +686,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(
                 ComboSpec(
                     combo_actions=self._skill_data.get_skill_data(name, "combo_action")
@@ -684,6 +725,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=1200
@@ -700,6 +742,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=1160
@@ -716,6 +759,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("True Thrust", "Raiden Thrust")),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -746,6 +790,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("True Thrust", "Raiden Thrust")),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=0
@@ -767,12 +812,13 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=700),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=600, application_delay=980
             ),
             has_aoe=True,
-            aoe_dropoff=0.5,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -781,13 +827,44 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(base_cast_time=0, animation_lock=600),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 duration=5 * 1000,
                 num_uses=1,
                 skill_allowlist=self.__drg_weapon_skills,
             ),
+            # TODO: add defensive spec
+        )
+
+    @GenericJobClass.is_a_skill
+    def feint(self):
+        name = "Feint"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.1,
+                    DamageInstanceClass.MAGICAL: 0.05,
+                },
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def second_wind(self):
+        name = "Second Wind"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=800),
         )
 
     # These skills do not damage, but grants resources/affects future skills.
@@ -797,12 +874,33 @@ class DrgSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def true_north(self):
         name = "True North"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def winged_glide(self):
         name = "Winged Glide"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
+    @GenericJobClass.is_a_skill
+    def bloodbath(self):
+        name = "Bloodbath"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            # TODO: add defensive spec
+        )
 
     @GenericJobClass.is_a_skill
     def elusive_jump(self):
@@ -811,7 +909,7 @@ class DrgSkills(GenericJobClass):
                 FollowUp(
                     skill=Skill(
                         name="Enhanced Piercing Talon",
-                        buff_spec=StatusEffectSpec(
+                        offensive_buff_spec=OffensiveStatusEffectSpec(
                             duration=15 * 1000,
                             num_uses=1,
                             skill_allowlist=("Piercing Talon",),
@@ -828,6 +926,7 @@ class DrgSkills(GenericJobClass):
         return Skill(
             name="Elusive Jump",
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(base_cast_time=0, animation_lock=800),
             follow_up_skills=drg_follow_ups,
         )
