@@ -102,8 +102,14 @@ ALL_DATA = {
     "High Jump": {90: {"potency": {"6.55": 400}}, 100: {"potency": {"7.0": 400}}},
     "Raiden Thrust": {90: {"potency": {"6.55": 280}}, 100: {"potency": {"7.0": 320}}},
     "Stardiver": {
-        90: {"potency": {"6.55": 620, "7.05": 620, "7.1": 720}},
-        100: {"potency": {"7.0": 620, "7.05": 720, "7.1": 820, "7.2": 840}},
+        90: {
+            "potency": {"6.55": 620, "7.05": 620, "7.1": 720},
+            "aoe_dropoff": {"6.55": 0.5, "7.3": 0.4},
+        },
+        100: {
+            "potency": {"7.0": 620, "7.05": 720, "7.1": 820, "7.2": 840},
+            "aoe_dropoff": {"7.0": 0.5, "7.3": 0.4},
+        },
     },
     "Draconian Fury": {90: {"potency": {"6.55": 130}}, 100: {"potency": {"7.0": 130}}},
     "Heavens' Thrust": {
@@ -152,7 +158,12 @@ ALL_DATA = {
             "potency_no_combo": {"7.0": 140},
         }
     },
-    "Starcross": {100: {"potency": {"7.0": 700, "7.05": 900, "7.1": 1000}}},
+    "Starcross": {
+        100: {
+            "potency": {"7.0": 700, "7.05": 900, "7.1": 1000},
+            "aoe_dropoff": {"7.0": 0.5, "7.3": 0.4},
+        }
+    },
     "Drakesbane": {
         90: {"potency": {"7.0": 400}},
         100: {"potency": {"7.0": 440, "7.2": 460}},
