@@ -79,12 +79,12 @@ ALL_DATA = {
         90: {
             "potency": {"6.55": 310, "7.0": 360, "7.01": 330},
             "potency_no_pos": {"6.55": 250, "7.0": 300, "7.01": 270},
-            "potency_fury": {"7.0": 400, "7.01": 420},
-            "potency_fury_no_pos": {"7.0": 460, "7.01": 480},
+            "potency_fury_no_pos": {"7.0": 400, "7.01": 420},
+            "potency_fury": {"7.0": 460, "7.01": 480},
         },
     },
     "Twin Snakes": {
-        90: {"potency": {"6.55": 280, "7.0": 380, "7.01": 420}},
+        90: {"potency": {"6.55": 280, "7.0": 380}},
         100: {"potency": {"7.0": 380, "7.01": 420}},
     },
     "Demolish": {
@@ -96,7 +96,7 @@ ALL_DATA = {
                 },
                 "7.0": None,
             },
-            "primary_application_delay": {"6.55": 1600},
+            "primary_application_delay": {"6.55": 0},
             "potency": {"6.55": 130, "7.0": 360, "7.01": 380},
             "potency_no_pos": {"6.55": 70, "7.0": 300, "7.01": 320},
         },
@@ -128,9 +128,12 @@ ALL_DATA = {
     "Elixir Field": {
         90: {
             "potency": {"6.55": 600, "7.0": 800},
-            "aoe_dropoff": {"6.55": 0.7, "7.2": 0.4},
+            "aoe_dropoff": {"6.55": 0.7, "7.2": 0.4, "7.3": 0.35},
+        },
+        100: {
+            "potency": {"7.0": 800},
+            "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4, "7.3": 0.35},
         },
-        100: {"potency": {"7.0": 800}, "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4}},
     },
     "Celestial Revolution": {
         90: {"potency": {"6.55": 450, "7.01": 600}},
@@ -141,7 +144,10 @@ ALL_DATA = {
         100: {"damage_mult": {"7.0": 1.15}, "duration": {"7.0": int(20.72 * 1000)}},
     },
     "Brotherhood": {
-        90: {"damage_mult": {"6.55": 1.05}, "duration": {"6.55": int(14.95 * 1000)}},
+        90: {
+            "damage_mult": {"6.55": 1.05},
+            "duration": {"6.55": int(14.95 * 1000), "7.0": int(19.95 * 1000)},
+        },
         100: {"damage_mult": {"7.0": 1.05}, "duration": {"7.0": int(19.95 * 1000)}},
     },
     "Riddle of Wind": {
@@ -198,18 +204,21 @@ ALL_DATA = {
     "Rising Phoenix": {
         90: {
             "potency": {"6.55": 700, "7.0": 900},
-            "aoe_dropoff": {"6.55": 0.7, "7.2": 0.4},
+            "aoe_dropoff": {"6.55": 0.7, "7.2": 0.4, "7.3": 0.35},
+        },
+        100: {
+            "potency": {"7.0": 900},
+            "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4, "7.3": 0.35},
         },
-        100: {"potency": {"7.0": 900}, "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4}},
     },
     "Phantom Rush": {
         90: {
             "potency": {"6.55": 1150, "7.0": 1300, "7.05": 1400},
-            "aoe_dropoff": {"6.55": 0.5, "7.2": 0.4},
+            "aoe_dropoff": {"6.55": 0.5, "7.2": 0.4, "7.3": 0.35},
         },
         100: {
             "potency": {"7.0": 1400, "7.05": 1500},
-            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4, "7.3": 0.35},
         },
     },
     "Leaping Opo": {100: {"potency": {"7.0": 260}, "potency_fury": {"7.0": 460}}},
@@ -230,18 +239,21 @@ ALL_DATA = {
         }
     },
     "Elixir Burst": {
-        100: {"potency": {"7.0": 900}, "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4}}
+        100: {
+            "potency": {"7.0": 900},
+            "aoe_dropoff": {"7.0": 0.7, "7.2": 0.4, "7.3": 0.35},
+        }
     },
     "Wind's Reply": {
         100: {
             "potency": {"7.0": 800, "7.05": 900, "7.2": 1040},
-            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4, "7.3": 0.35},
         },
     },
     "Fire's Reply": {
         100: {
             "potency": {"7.0": 1100, "7.05": 1200, "7.2": 1400},
-            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4},
+            "aoe_dropoff": {"7.0": 0.5, "7.2": 0.4, "7.3": 0.35},
         }
     },
     "Raptor's Fury": {
