@@ -65,6 +65,10 @@ ALL_DATA = {
         90: {"potency": {"6.55": 80}, "duration": {"6.55": 18 * 1000}},
         100: {"potency": {"7.0": 80}, "duration": {"7.0": 18 * 1000}},
     },
+    "Doton": {
+        90: {"potency": {"6.55": 80},},
+        100: {"potency": {"7.0": 80},},
+    },
     "Hollow Nozuchi": {
         90: {"potency": {"6.55": 50, "7.25": 70}},
         100: {"potency": {"7.0": 50, "7.25": 70}},
