@@ -1,13 +1,24 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
+from ama_xiv_combat_sim.simulator.calcs.damage_instance_class import (
+    DamageInstanceClass,
+)
 from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
+from ama_xiv_combat_sim.simulator.specs.trigger_spec import TriggerSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.melee.sam_data import (
     all_sam_skills,
@@ -25,8 +36,9 @@ class SamSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(damage_mult=1.13, duration=40000),
+                offensive_buff_spec=OffensiveStatusEffectSpec(
+                    damage_mult=1.13, duration=40000
+                ),
             ),
             delay_after_parent_application=650,
         )
@@ -36,8 +48,7 @@ class SamSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     haste_time_reduction=0.13,
                     auto_attack_delay_reduction=0.13,
                     duration=40000,
@@ -52,6 +63,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -66,6 +78,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -81,6 +94,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -110,6 +124,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (
@@ -153,6 +168,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -171,7 +187,7 @@ class SamSkills(GenericJobClass):
         enhanced_enpi_follow_up = FollowUp(
             skill=Skill(
                 name="Enhanced Enpi",
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=15 * 1000,
@@ -185,6 +201,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=450
@@ -214,6 +231,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (
@@ -294,6 +312,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (ComboSpec(combo_actions=("Jinpu",)),),
@@ -341,7 +360,6 @@ class SamSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                is_GCD=False,
                 damage_spec=DamageSpec(
                     potency=self._skill_data.get_potency(name),
                     damage_class=DamageClass.PHYSICAL_DOT,
@@ -359,6 +377,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=self.__get_iaijutsu_timing(),
             follow_up_skills=(self.__get_higanbana_follow_up(),),
@@ -370,6 +389,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=self.__get_iaijutsu_timing(),
         )
@@ -380,6 +400,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -395,6 +416,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=self.instant_timing_spec,
             follow_up_skills=(self.__get_higanbana_follow_up(),),
@@ -406,6 +428,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -418,6 +441,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -453,6 +477,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (ComboSpec(combo_actions=("Fuko",)),),
@@ -517,6 +542,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (ComboSpec(combo_actions=("Shifu",)),),
@@ -576,6 +602,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             ignored_conditions_for_bonus_potency=("Meikyo Shisui",),
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (ComboSpec(combo_actions=("Fuko",)),),
@@ -603,6 +630,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec={
                 SimConsts.DEFAULT_CONDITION: (
                     ComboSpec(
@@ -646,6 +674,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -658,6 +687,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=490
@@ -670,6 +700,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
@@ -683,12 +714,13 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
             has_aoe=True,
-            aoe_dropoff=0.25,
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -697,6 +729,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=670
@@ -709,6 +742,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=580
@@ -725,6 +759,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=580
@@ -737,6 +772,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -751,6 +787,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -771,6 +808,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -790,6 +828,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1030
@@ -806,6 +845,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=1300, animation_lock=650, application_delay=360
@@ -820,6 +860,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -842,6 +883,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=360
@@ -856,6 +898,7 @@ class SamSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -870,14 +913,80 @@ class SamSkills(GenericJobClass):
             ),
         )
 
+    @GenericJobClass.is_a_skill
+    def tengentsu_foresight(self):
+        name = "Tengentsu's Foresight"
+
+        # TODO: this actually only triggers on hit.
+        # How to link back?
+        return (
+            Skill(
+                name=f"{name}",
+                is_GCD=False,
+                skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+                timing_spec=self.uncontrolled_timing_spec,
+                defensive_buff_spec=DefensiveStatusEffectSpec(
+                    damage_reductions=0.1,
+                    duration=9 * 1000,
+                ),
+                heal_spec=HealSpec(hot_potency=200, duration=9 * 1000),
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def tengentsu(self):
+        name = "Tengentsu"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=4 * 1000,
+                num_uses=1,
+            ),
+            trigger_spec=TriggerSpec(triggers=("Tengentsu's Foresight",)),
+        )
+
+    @GenericJobClass.is_a_skill
+    def feint(self):
+        name = "Feint"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions={
+                    DamageInstanceClass.PHYSICAL: 0.1,
+                    DamageInstanceClass.MAGICAL: 0.05,
+                },
+                duration=15 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def second_wind(self):
+        name = "Second Wind"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=800),
+        )
+
     @GenericJobClass.is_a_skill
     def meikyo_shisui(self):
         name = "Meikyo Shisui"
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 add_to_skill_modifier_condition=True,
                 num_uses=3,
                 duration=int(self._skill_data.get_skill_data(name, "duration")),
@@ -898,19 +1007,40 @@ class SamSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def true_north(self):
         name = "True North"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
-
-    @GenericJobClass.is_a_skill
-    def tengentsu(self):
-        name = "Tengentsu"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def hagakure(self):
         name = "Hagakure"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
 
     @GenericJobClass.is_a_skill
     def ikishoten(self):
         name = "Ikishoten"
-        return Skill(name=name, is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
+    @GenericJobClass.is_a_skill
+    def bloodbath(self):
+        name = "Bloodbath"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            # TODO: add defensive spec
+        )
