@@ -110,37 +110,55 @@ ALL_DATA = {
         100: {"potency": {"7.0": 120, "7.2": 100}},
     },
     "Hissatsu: Guren": {
-        90: {"potency": {"6.55": 500, "7.2": 400}},
-        100: {"potency": {"7.0": 500, "7.2": 400}},
+        90: {
+            "potency": {"6.55": 500, "7.2": 400},
+            "aoe_dropoff": {"6.55": 0.25, "7.3": 0},
+        },
+        100: {
+            "potency": {"7.0": 500, "7.2": 400},
+            "aoe_dropoff": {"7.0": 0.25, "7.3": 0},
+        },
     },
     "Hissatsu: Senei": {
         90: {"potency": {"6.55": 860, "7.05": 800}},
         100: {"potency": {"7.0": 860, "7.05": 800}},
     },
     "Shoha": {
-        90: {"potency": {"6.55": 560}, "aoe_dropoff": {"6.55": 0.65, "7.2": 0.5}},
-        100: {"potency": {"7.0": 640}, "aoe_dropoff": {"7.0": 0.65, "7.2": 0.5}},
+        90: {
+            "potency": {"6.55": 560},
+            "aoe_dropoff": {"6.55": 0.65, "7.2": 0.5, "7.3": 0.4},
+        },
+        100: {
+            "potency": {"7.0": 640},
+            "aoe_dropoff": {"7.0": 0.65, "7.2": 0.5, "7.3": 0.4},
+        },
     },
     "Shoha II": {90: {"potency": {"6.55": 200}}},
     "Fuko": {90: {"potency": {"6.55": 100}}, 100: {"potency": {"7.0": 100}}},
     "Ogi Namikiri": {
-        90: {"potency": {"6.55": 860}, "aoe_dropoff": {"6.55": 0.75, "7.2": 0.5}},
+        90: {
+            "potency": {"6.55": 860},
+            "aoe_dropoff": {"6.55": 0.75, "7.2": 0.5, "7.3": 0.4},
+        },
         100: {
             "potency": {"7.0": 900, "7.2": 1000},
-            "aoe_dropoff": {"7.0": 0.75, "7.2": 0.5},
+            "aoe_dropoff": {"7.0": 0.75, "7.2": 0.5, "7.3": 0.4},
         },
     },
     "Kaeshi: Namikiri": {
-        90: {"potency": {"6.55": 860}, "aoe_dropoff": {"6.55": 0.75, "7.2": 0.5}},
+        90: {
+            "potency": {"6.55": 860},
+            "aoe_dropoff": {"6.55": 0.75, "7.2": 0.5, "7.3": 0.4},
+        },
         100: {
             "potency": {"7.0": 900, "7.2": 1000},
-            "aoe_dropoff": {"7.0": 0.75, "7.2": 0.5},
+            "aoe_dropoff": {"7.0": 0.75, "7.2": 0.5, "7.3": 0.4},
         },
     },
     "Zanshin": {
         100: {
             "potency": {"7.0": 900, "7.05": 820, "7.1": 900, "7.2": 940},
-            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.5},
+            "aoe_dropoff": {"7.0": 0.6, "7.2": 0.5, "7.3": 0.4},
         }
     },
     "Tendo Goken": {100: {"potency": {"7.0": 420, "7.05": 410}}},
@@ -158,13 +176,9 @@ ALL_DATA = {
         }
     },
     "Meikyo Shisui": {
-        90: {
-            "duration": {"6.55": 15.1*1000, "7.0": 20.1*1000}
-        },
-        100: {
-            "duration": {"7.0": 20.1*1000}
-        }
-    }
+        90: {"duration": {"6.55": 15.1 * 1000, "7.0": 20.1 * 1000}},
+        100: {"duration": {"7.0": 20.1 * 1000}},
+    },
 }
 
 for k, v in ALL_DATA.items():
