@@ -1,12 +1,20 @@
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.channeling_spec import ChannelingSpec
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.tank.pld_data import (
@@ -34,7 +42,7 @@ class PldSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name=name,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=4,
                     duration=30 * 1000,
@@ -55,8 +63,7 @@ class PldSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name="Divine Might",
-                is_GCD=False,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     add_to_skill_modifier_condition=True,
                     num_uses=1,
                     duration=30 * 1000,
@@ -73,6 +80,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -85,6 +93,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -98,7 +107,10 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
-            buff_spec=StatusEffectSpec(duration=20000, damage_mult=1.25),
+            skill_type=SkillType.ABILITY,
+            offensive_buff_spec=OffensiveStatusEffectSpec(
+                duration=20000, damage_mult=1.25
+            ),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
@@ -110,6 +122,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -130,6 +143,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(),),
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
@@ -144,6 +158,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=446
@@ -156,6 +171,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=889
@@ -186,6 +202,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             combo_spec=(ComboSpec(combo_actions=("Total Eclipse",)),),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
@@ -205,7 +222,6 @@ class PldSkills(GenericJobClass):
         name = "Circle of Scorn (dot)"
         circle_of_scorn_dot_pld = Skill(
             name=name,
-            is_GCD=False,
             damage_spec=DamageSpec(
                 potency=self._skill_data.get_potency(name),
                 damage_class=DamageClass.PHYSICAL_DOT,
@@ -216,6 +232,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1023
             ),
@@ -238,6 +255,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=534
@@ -250,6 +268,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -274,6 +293,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_skill_data(name, "potency")
@@ -292,6 +312,7 @@ class PldSkills(GenericJobClass):
                     )
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=1500,
@@ -329,6 +350,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
@@ -351,7 +373,7 @@ class PldSkills(GenericJobClass):
                     )
                 },
                 has_aoe=True,
-                aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff")
+                aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
             ),
             delay_after_parent_application=1290,
             primary_target_only=False,
@@ -359,6 +381,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
@@ -374,6 +397,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -393,6 +417,7 @@ class PldSkills(GenericJobClass):
                     )
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=1500,
@@ -427,6 +452,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=578
@@ -439,6 +465,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1293
@@ -453,6 +480,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1160
@@ -467,6 +495,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             damage_spec=DamageSpec(potency=self._skill_data.get_potency(name)),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1290
@@ -479,6 +508,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(combo_group=1),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -488,6 +518,7 @@ class PldSkills(GenericJobClass):
                     potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
@@ -501,6 +532,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -519,6 +551,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Confiteor",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -528,11 +561,12 @@ class PldSkills(GenericJobClass):
                     potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=666
             ),
             has_aoe=True,
-            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff")
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -541,6 +575,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Blade of Faith",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -550,11 +585,12 @@ class PldSkills(GenericJobClass):
                     potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=891
             ),
             has_aoe=True,
-            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff")
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -563,6 +599,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.SPELL,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Blade of Truth",)),),
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
@@ -572,11 +609,12 @@ class PldSkills(GenericJobClass):
                     potency=self._skill_data.get_skill_data(name, "potency_req")
                 ),
             },
+            heal_spec=HealSpec(potency=400),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=891
             ),
             has_aoe=True,
-            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff")
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
         )
 
     @GenericJobClass.is_a_skill
@@ -587,6 +625,7 @@ class PldSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(
                     potency=self._skill_data.get_potency(name)
@@ -596,7 +635,259 @@ class PldSkills(GenericJobClass):
                 base_cast_time=0, animation_lock=650, application_delay=1160
             ),
             has_aoe=True,
-            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff")
+            aoe_dropoff=self._skill_data.get_skill_data(name, "aoe_dropoff"),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def knights_resolve(self):
+        name = "Knight's Resolve"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            # Super gross way to ensure we don't double count a
+            # Knight's Resolve buff.
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Other": DefensiveStatusEffectSpec(
+                    damage_reductions=0.15,
+                    duration=4 * 1000,
+                    is_party_effect=True,
+                ),
+            },
+            off_class_default_condition="Other",
+        )
+
+    @GenericJobClass.is_a_skill
+    def holy_sheltron(self):
+        resolve_follow_up = FollowUp(
+            skill=self.knights_resolve(), delay_after_parent_application=0
+        )
+        benediction_follow_up = FollowUp(
+            skill=self.knights_benediction(), delay_after_parent_application=0
+        )
+
+        name = "Holy Sheltron"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.15, duration=8 * 1000
+            ),
+            follow_up_skills=(
+                resolve_follow_up,
+                benediction_follow_up,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def sentinel(self):
+        if self._level >= 92:
+            return None
+        name = "Sentinel"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.30, duration=15 * 1000
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def bulwark(self):
+        name = "Bulwark"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                increase_block_chance=1.0,
+                duration=10 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def divine_veil(self):
+        name = "Divine Veil"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec=ShieldSpec(
+                # Fucking gross. Fuck.
+                shield_on_your_max_hp=0.1,
+                duration=30 * 1000,
+                is_party_effect=True,
+                is_aoe=True,
+            ),
+            heal_spec=HealSpec(potency=400, is_party_effect=True, is_aoe=True),
+        )
+
+    @GenericJobClass.is_a_skill
+    def clemency(self):
+        heal_self_follow_up = FollowUp(
+            skill=Skill(
+                name="Clemency (Heal)",
+                is_GCD=False,
+                heal_spec=HealSpec(potency=500),
+                skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+                timing_spec=self.uncontrolled_timing_spec,
+            ),
+            delay_after_parent_application=0,
+        )
+        return Skill(
+            name="Clemency",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Target": HealSpec(potency=1000, is_party_effect=True),
+            },
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: (heal_self_follow_up,),
+                "Target": tuple(),
+            },
+            # If PLD heals itself, just specify it as "Target".
+            off_class_default_condition="Target",
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def knights_benediction(self):
+        name = "Knight's Benediction"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec=HealSpec(hot_potency=250, duration=12 * 1000),
+        )
+
+    @GenericJobClass.is_a_skill
+    def intervention(self):
+        # Because if this is on YOU, it's 10%, but someone else is 15%.
+        personal_knights_resolve_follow_up = FollowUp(
+            skill=Skill(
+                name="Knight's Resolve",
+                is_GCD=False,
+                skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+                timing_spec=self.uncontrolled_timing_spec,
+                defensive_buff_spec=DefensiveStatusEffectSpec(
+                    damage_reductions=0.10,
+                    duration=4 * 1000,
+                ),
+            ),
+            delay_after_parent_application=0,
+        )
+        benediction_follow_up = FollowUp(
+            skill=self.knights_benediction(), delay_after_parent_application=0
+        )
+
+        regular_def = DefensiveStatusEffectSpec(
+            damage_reductions=0.10,
+            duration=8 * 1000,
+            is_party_effect=True,
+        )
+        buffed_def = DefensiveStatusEffectSpec(
+            damage_reductions=0.20,
+            duration=8 * 1000,
+            is_party_effect=True,
+        )
+
+        name = "Intervention"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: regular_def,
+                "Rampart": buffed_def,
+                "Guardian": buffed_def,
+                "Guardian, Rampart": buffed_def,
+            },
+            follow_up_skills=(
+                personal_knights_resolve_follow_up,
+                benediction_follow_up,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def guardian(self):
+        if self._level < 92:
+            return None
+        return Skill(
+            name="Guardian",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.4,
+                duration=15 * 1000,
+                add_to_skill_modifier_condition=True,
+            ),
+            shield_spec=ShieldSpec(potency=1000, duration=15 * 1000),
+        )
+
+    @GenericJobClass.is_a_skill
+    def hallowed_ground(self):
+        return Skill(
+            name="Hallowed Ground",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                is_invuln=True,
+                duration=10 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def passage_of_arms(self):
+        name = "Passage of Arms"
+
+        block_follow_up = FollowUp(
+            skill=Skill(
+                name=f"{name} (Block)",
+                defensive_buff_spec=DefensiveStatusEffectSpec(
+                    increase_block_chance=1.0,
+                    duration=18 * 1000,
+                ),
+            ),
+            delay_after_parent_application=0,
+        )
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec={
+                SimConsts.DEFAULT_CONDITION: self.instant_timing_spec,
+                "Cancel": self.uncontrolled_timing_spec,
+            },
+            channeling_spec={
+                SimConsts.DEFAULT_CONDITION: ChannelingSpec(duration=18 * 1000),
+                "Cancel": None,
+            },
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: DefensiveStatusEffectSpec(
+                    damage_reductions=0.15,
+                    duration=18 * 1000,
+                    is_party_effect=True,
+                ),
+                "Cancel": DefensiveStatusEffectSpec(
+                    expires_status_effects=(name, f"{name} (Block)")
+                ),
+            },
+            follow_up_skills=(block_follow_up,),
         )
 
     # These skills do not damage, but grants resources/affects future skills.
@@ -604,35 +895,66 @@ class PldSkills(GenericJobClass):
     # not their effect.
 
     @GenericJobClass.is_a_skill
-    def passage_of_arms(self):
-        name = "Passage of Arms"
+    def cover(self):
+        # TODO: implement. Fuck this skill.
         return Skill(
-            name=name,
+            name="Cover",
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
+
+    @GenericJobClass.is_a_skill
+    def provoke(self):
+        return Skill(
+            name="Provoke",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=self.instant_timing_spec,
-            channeling_spec=ChannelingSpec(duration=18000),
         )
 
     @GenericJobClass.is_a_skill
     def rampart(self):
-        return Skill(name="Rampart", is_GCD=False, timing_spec=self.instant_timing_spec)
-
-    @GenericJobClass.is_a_skill
-    def provoke(self):
-        return Skill(name="Provoke", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Rampart",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.2,
+                hp_recovery_up_via_healing_actions=0.15,
+                duration=20 * 1000,
+                add_to_skill_modifier_condition=True,
+            ),
+        )
 
     @GenericJobClass.is_a_skill
     def reprisal(self):
         return Skill(
-            name="Reprisal", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Reprisal",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=15 * 1000,
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def arms_length(self):
         return Skill(
-            name="Arm's Length", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Arm's Length",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def shirk(self):
-        return Skill(name="Shirk", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Shirk",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
