@@ -1,13 +1,22 @@
+from itertools import chain, combinations
+
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.calcs.forced_crit_or_dh import ForcedCritOrDH
-
 from ama_xiv_combat_sim.simulator.game_data.generic_job_class import GenericJobClass
+from ama_xiv_combat_sim.simulator.game_data.skill_type import SkillType
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.combo_spec import ComboSpec
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
+from ama_xiv_combat_sim.simulator.specs.heal_spec import HealSpec
 from ama_xiv_combat_sim.simulator.specs.follow_up import FollowUp
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.shield_spec import ShieldSpec
+from ama_xiv_combat_sim.simulator.specs.defensive_status_effect_spec import (
+    DefensiveStatusEffectSpec,
+)
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import (
+    OffensiveStatusEffectSpec,
+)
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 
 from ama_xiv_combat_sim.simulator.game_data.class_skills.tank.war_data import (
@@ -25,7 +34,7 @@ class WarSkills(GenericJobClass):
         return FollowUp(
             skill=Skill(
                 name="Surging Tempest",
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     duration=30000,
                     max_duration=60000,
                     damage_mult=1.10,
@@ -42,6 +51,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.AUTO,
             timing_spec=self.auto_timing_spec,
             damage_spec=DamageSpec(
                 potency=90, damage_class=DamageClass.AUTO, trait_damage_mult_override=1
@@ -54,6 +64,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=532
             ),
@@ -67,6 +78,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
@@ -87,6 +99,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1515
             ),
@@ -99,6 +112,10 @@ class WarSkills(GenericJobClass):
                     potency=self._skill_data.get_potency_no_combo(name)
                 ),
             },
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: HealSpec(potency=250),
+                "No Combo": None,
+            },
         )
 
     @GenericJobClass.is_a_skill
@@ -106,7 +123,7 @@ class WarSkills(GenericJobClass):
         surging_tempest_inital_follow_up = FollowUp(
             skill=Skill(
                 name="Surging Tempest",
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     duration=31600,
                     max_duration=60000,
                     damage_mult=1.10,
@@ -137,6 +154,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(base_cast_time=0, animation_lock=650),
             combo_spec=(ComboSpec(combo_actions=("Maim",)),),
             follow_up_skills={
@@ -158,7 +176,7 @@ class WarSkills(GenericJobClass):
         ir_surging_tempest_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     duration=10000,
                     max_duration=60000,
                     damage_mult=1.10,
@@ -173,10 +191,11 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=0
             ),
-            buff_spec=StatusEffectSpec(
+            offensive_buff_spec=OffensiveStatusEffectSpec(
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 num_uses=3,
@@ -192,6 +211,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
@@ -204,6 +224,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=667
             ),
@@ -216,6 +237,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=623
             ),
@@ -228,6 +250,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=1300, application_delay=1160
             ),
@@ -248,6 +271,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=937
             ),
@@ -264,6 +288,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1430
             ),
@@ -281,6 +306,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=713
             ),
@@ -293,6 +319,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=625
             ),
@@ -307,7 +334,7 @@ class WarSkills(GenericJobClass):
         mythril_tempest_inital_follow_up = FollowUp(
             skill=Skill(
                 name=name,
-                buff_spec=StatusEffectSpec(
+                offensive_buff_spec=OffensiveStatusEffectSpec(
                     duration=30470,
                     max_duration=60000,
                     damage_mult=1.10,
@@ -340,6 +367,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(base_cast_time=0, animation_lock=650),
             combo_spec=(ComboSpec(combo_actions=("Overpower",)),),
             follow_up_skills={
@@ -362,6 +390,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=668
             ),
@@ -375,6 +404,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1831
             ),
@@ -383,7 +413,7 @@ class WarSkills(GenericJobClass):
         )
 
     @GenericJobClass.is_a_skill
-    def vengance(self):
+    def vengeance(self):
         if self._level >= 92:
             return None
 
@@ -391,6 +421,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: None,
                 "Retaliation": DamageSpec(potency=self._skill_data.get_potency(name)),
@@ -401,6 +432,26 @@ class WarSkills(GenericJobClass):
                     base_cast_time=0, animation_lock=0, application_delay=534
                 ),
             },
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.3,
+                duration=15 * 1000,
+                add_to_skill_modifier_condition=True,
+            ),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def primeval_impulse_heal(self):
+        name = "Primeval Impulse"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Damnation": HealSpec(hot_potency=300, duration=15 * 1000),
+            },
         )
 
     @GenericJobClass.is_a_skill
@@ -408,10 +459,15 @@ class WarSkills(GenericJobClass):
         if self._level < 92:
             return None
 
+        _primeval_impulse_heal_follow_up = FollowUp(
+            skill=self.primeval_impulse_heal(), delay_after_parent_application=15 * 1000
+        )
+
         name = "Damnation"
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: None,
                 "Retaliation": DamageSpec(potency=self._skill_data.get_potency(name)),
@@ -422,6 +478,12 @@ class WarSkills(GenericJobClass):
                     base_cast_time=0, animation_lock=0, application_delay=534
                 ),
             },
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.4,
+                add_to_skill_modifier_condition=True,
+                duration=15 * 1000,
+            ),
+            follow_up_skills=(_primeval_impulse_heal_follow_up,),
         )
 
     @GenericJobClass.is_a_skill
@@ -432,6 +494,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=False,
+            skill_type=SkillType.ABILITY,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1150
             ),
@@ -452,6 +515,7 @@ class WarSkills(GenericJobClass):
         return Skill(
             name=name,
             is_GCD=True,
+            skill_type=SkillType.WEAPONSKILL,
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=1300, application_delay=1060
             ),
@@ -472,71 +536,271 @@ class WarSkills(GenericJobClass):
     @GenericJobClass.is_a_skill
     def infuriate(self):
         return Skill(
-            name="Infuriate", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Infuriate",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def defiance(self):
         return Skill(
-            name="Defiance", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Defiance",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
-    def thrill(self):
+    def thrill_of_battle(self):
         return Skill(
-            name="Thrill of Battle", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Thrill of Battle",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                # TODO: hp_recovery_up_via_healing_actions is from SELF only. Can add a new field I guess, but is there a more robust way?
+                max_hp_mult=1.2,
+                hp_recovery_up_via_healing_actions=0.2,
+                duration=10 * 1000,
+                add_to_skill_modifier_condition=True,
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def holmgang(self):
         return Skill(
-            name="Holmgang", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Holmgang",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                is_invuln=True, duration=10 * 1000
+            ),
         )
 
     @GenericJobClass.is_a_skill
     def equilibrium(self):
+        name = "Equilibrium"
         return Skill(
-            name="Equilibrium", is_GCD=False, timing_spec=self.instant_timing_spec
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            heal_spec=HealSpec(potency=1200, hot_potency=200, duration=15 * 1000),
         )
 
     @GenericJobClass.is_a_skill
     def shake(self):
+        name = "Shake It Off"
+
+        def get_shield_and_defensive_specs():
+            if self._level < 92:
+                shake_aux_skills = ("Bloodwhetting", "Thrill of Battle", "Vengeance")
+            else:
+                shake_aux_skills = ("Bloodwhetting", "Thrill of Battle", "Damnation")
+
+            shield_spec = {}
+            defensive_status_effect_spec = {}
+            skills_powerset = list(
+                chain.from_iterable(
+                    combinations(shake_aux_skills, r)
+                    for r in range(len(shake_aux_skills) + 1)
+                )
+            )
+            for sk in skills_powerset:
+                key = ",".join(sk) if len(sk) > 0 else SimConsts.DEFAULT_CONDITION
+                shield_spec[key] = ShieldSpec(
+                    shield_as_perc_of_max_hp=0.15 + 0.02 * len(sk),
+                    duration=30 * 1000,
+                    is_party_effect=True,
+                )
+                defensive_status_effect_spec[key] = DefensiveStatusEffectSpec(
+                    expires_status_effects=tuple(sk)
+                )
+            return shield_spec, defensive_status_effect_spec
+
+        shield_spec, defensive_status_effect_spec = get_shield_and_defensive_specs()
+
         return Skill(
-            name="Shake It Off", is_GCD=False, timing_spec=self.instant_timing_spec
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            shield_spec=shield_spec,
+            defensive_buff_spec=defensive_status_effect_spec,
+            heal_spec=HealSpec(
+                potency=300,
+                hot_potency=100,
+                duration=15 * 1000,
+                is_party_effect=True,
+                is_aoe=True,
+            ),
+            # Kinda ugly to model here and not on the Damnation expiry itself, but this will work...
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: tuple(),
+                "Damnation": (
+                    FollowUp(
+                        skill=self.primeval_impulse_heal(),
+                        delay_after_parent_application=0,
+                    ),
+                ),
+            },
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def nascent_flash_heal(self):
+        name = "Nascent Flash (Heal)"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec=HealSpec(potency=400),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def nascent_glint_heal(self):
+        name = "Nascent Glint (Heal)"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            heal_spec=HealSpec(potency=400, is_party_effect=True),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def stem_the_flow(self):
+        name = "Stem the Flow"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=4 * 1000,
+                is_party_effect=True,
+            ),
+        )
+
+    # For logs parsing convenience
+    @GenericJobClass.is_a_skill
+    def stem_the_tide(self):
+        name = "Stem the Tide"
+        return Skill(
+            name=name,
+            is_GCD=False,
+            skill_type=SkillType.UNCONTROLLED_FOLLOW_UP,
+            timing_spec=self.uncontrolled_timing_spec,
+            shield_spec=ShieldSpec(
+                potency=400, duration=20 * 1000, is_party_effect=True
+            ),
         )
 
     @GenericJobClass.is_a_skill
-    def nascent(self):
+    def nascent_flash(self):
+        _tide_follow_up = FollowUp(
+            skill=self.stem_the_tide(), delay_after_parent_application=0
+        )
+        _flow_follow_up = FollowUp(
+            skill=self.stem_the_flow(), delay_after_parent_application=0
+        )
+
         return Skill(
-            name="Nascent Flash", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Nascent Flash",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec={
+                SimConsts.DEFAULT_CONDITION: None,
+                "Other": DefensiveStatusEffectSpec(
+                    damage_reductions=0.1,
+                    is_party_effect=True,
+                    duration=8 * 1000,
+                ),
+            },
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: tuple(),
+                "Other": (_tide_follow_up, _flow_follow_up),
+            },
+            off_class_default_condition="Other",
         )
 
     @GenericJobClass.is_a_skill
     def bloodwhetting(self):
+        _tide_follow_up = FollowUp(
+            skill=self.stem_the_tide(), delay_after_parent_application=0
+        )
+        _flow_follow_up = FollowUp(
+            skill=self.stem_the_flow(), delay_after_parent_application=0
+        )
+
         return Skill(
-            name="Bloodwhetting", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Bloodwhetting",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1, duration=8 * 1000
+            ),
+            follow_up_skills=(_tide_follow_up, _flow_follow_up),
         )
 
     @GenericJobClass.is_a_skill
     def rampart(self):
-        return Skill(name="Rampart", is_GCD=False, timing_spec=self.instant_timing_spec)
-
-    @GenericJobClass.is_a_skill
-    def provoke(self):
-        return Skill(name="Provoke", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Rampart",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_buff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.2,
+                hp_recovery_up_via_healing_actions=0.15,
+                duration=20 * 1000,
+            ),
+        )
 
     @GenericJobClass.is_a_skill
     def reprisal(self):
         return Skill(
-            name="Reprisal", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Reprisal",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+            defensive_debuff_spec=DefensiveStatusEffectSpec(
+                damage_reductions=0.1,
+                duration=15 * 1000,
+            ),
+        )
+
+    @GenericJobClass.is_a_skill
+    def provoke(self):
+        return Skill(
+            name="Provoke",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def arms_length(self):
         return Skill(
-            name="Arm's Length", is_GCD=False, timing_spec=self.instant_timing_spec
+            name="Arm's Length",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
         )
 
     @GenericJobClass.is_a_skill
     def shirk(self):
-        return Skill(name="Shirk", is_GCD=False, timing_spec=self.instant_timing_spec)
+        return Skill(
+            name="Shirk",
+            is_GCD=False,
+            skill_type=SkillType.ABILITY,
+            timing_spec=self.instant_timing_spec,
+        )
