@@ -6,7 +6,7 @@ from ama_xiv_combat_sim.simulator.skills.create_skill_library import (
 )
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
-from ama_xiv_combat_sim.simulator.specs.status_effect_spec import StatusEffectSpec
+from ama_xiv_combat_sim.simulator.specs.offensive_status_effect_spec import OffensiveStatusEffectSpec
 from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 from ama_xiv_combat_sim.simulator.stats import Stats
 from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
@@ -153,7 +153,7 @@ class TestJobsUnified71(TestClass):
 
         debuff_skill = Skill(
             name="Vulnerability Down",
-            debuff_spec=StatusEffectSpec(
+            offensive_debuff_spec=OffensiveStatusEffectSpec(
                 duration=9999000, damage_mult=0.5, is_party_effect=True
             ),
             timing_spec=TimingSpec(
