@@ -39,6 +39,7 @@ class TestJobsMultiUnified72(TestClass):
             level=self.__level,
         )
         base_oracle = 42847
+        base_earthly_star = 14801
         skills_and_expected_damages = (
             (
                 "Oracle",
@@ -46,6 +47,12 @@ class TestJobsMultiUnified72(TestClass):
                 SkillModifier(),
                 (base_oracle, 0.5 * base_oracle, 0.5 * base_oracle),
             ),
+            (
+                "Earthly Star",
+                "t1, t2, t3",
+                SkillModifier(),
+                (base_earthly_star, base_earthly_star, base_earthly_star),
+            ),
         )
         return self.__job_class_tester.test_multi_target_skills(
             stats, skills_and_expected_damages
