@@ -1,3 +1,6 @@
+import copy
+import os
+
 from ama_xiv_combat_sim.simulator.rotation_import_utils.csv_utils import CSVUtils
 from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
 from ama_xiv_combat_sim.simulator.stats import Stats
@@ -16,30 +19,33 @@ from ama_xiv_combat_sim.simulator.timeline_builders.snapshot_and_application_eve
 class TestCSVUtils(TestClass):
     def __init__(self):
         super().__init__()
-        self.__test_csv_filename1 = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation1.csv"
+        base_dir = os.path.dirname(os.path.realpath(__file__))
+        self.__test_csv_filename1 = os.path.join(base_dir, "test_rotation1.csv")
+        self.__test_bulk_filename1 = os.path.join(base_dir, "test_bulk_rotation1.csv")
+        self.__test_bulk_filename2 = os.path.join(base_dir, "test_bulk_rotation2.csv")
+        self.__test_bulk_filename3 = os.path.join(base_dir, "test_bulk_rotation3.csv")
+        self.__test_bulk_filename4 = os.path.join(base_dir, "test_bulk_rotation4.csv")
+        self.__test_bulk_filename5 = os.path.join(base_dir, "test_bulk_rotation5.csv")
+        self.__test_csv_filename_nonexistent_skill = os.path.join(
+            base_dir, "test_rotation_nonexistent_skill.csv"
         )
-        self.__test_csv_filename_nonexistent_skill = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_nonexistent_skill.csv"
+        self.__test_csv_filename_downtime_windows = os.path.join(
+            base_dir, "test_rotation_downtime_windows.csv"
         )
-        self.__test_csv_filename_downtime_windows = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_downtime_windows.csv"
+        self.__test_csv_filename_multitarget = os.path.join(
+            base_dir, "test_rotation_multitarget.csv"
         )
-        self.__test_csv_filename_multitarget = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_multitarget.csv"
+        self.__test_csv_rotation_stats = os.path.join(
+            base_dir, "test_rotation_stats.csv"
         )
-        self.__test_csv_rotation_stats = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_stats.csv"
+        self.__test_csv_filename_enable_autos = os.path.join(
+            base_dir, "test_rotation_enable_autos.csv"
         )
-        self.__test_csv_filename_enable_autos = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_enable_autos.csv"
-        )
-        self.__test_csv_filename_lb = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_lb.csv"
-        )
-        self.__test_csv_filename_start_time = (
-            "../ama_xiv_combat_sim/simulator/rotation_import_utils/test_rotation_start_time.csv"
+        self.__test_csv_filename_lb = os.path.join(base_dir, "test_rotation_lb.csv")
+        self.__test_csv_filename_start_time = os.path.join(
+            base_dir, "test_rotation_start_time.csv"
         )
+
         self.__skill_library = create_test_skill_library()
 
         self.__stats = Stats(
@@ -54,6 +60,25 @@ class TestCSVUtils(TestClass):
             version="test",
         )
 
+    def __do_rb_compare(self, result_rbs, expected):
+        test_passed = True
+        err_msg = ""
+        if expected.keys() != result_rbs.keys():
+            test_passed = False
+            err_msg = f"Did not get expected keys for rotations. Expected: {expected.keys()} vs. Acual: {result_rbs.keys()}"
+
+        for player_name, rb in result_rbs.items():
+            result = rb.get_skill_timing().get_q()
+            result = [x[1:4] for x in rb.get_skill_timing().get_q()]
+
+            is_passed, this_err_msg = self._compare_sequential(
+                result, expected[player_name]
+            )
+            test_passed &= is_passed
+            err_msg += this_err_msg
+
+        return test_passed, err_msg
+
     @TestClass.is_a_test
     def test_csv_read1(self):
         rb = RotationBuilder(
@@ -115,15 +140,14 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         for tmp, tmp2 in zip(result, expected):
             if tmp != tmp2:
-                print('---')
+                print("---")
                 for i, _ in enumerate(tmp):
                     if tmp[i] != tmp2[i]:
-                        print(f'{tmp[i]} vs {tmp2[i]}')
-            
-        
+                        print(f"{tmp[i]} vs {tmp2[i]}")
+
         return self._compare_sequential(result, expected)
 
     @TestClass.is_a_test
@@ -134,7 +158,9 @@ class TestCSVUtils(TestClass):
             ignore_trailing_dots=True,
             enable_autos=False,
         )
-        rb, _ = CSVUtils.populate_rotation_from_csv(rb, self.__test_csv_filename_start_time)
+        rb, _ = CSVUtils.populate_rotation_from_csv(
+            rb, self.__test_csv_filename_start_time
+        )
 
         expected = (
             (
@@ -186,15 +212,14 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         for tmp, tmp2 in zip(result, expected):
             if tmp != tmp2:
-                print('---')
+                print("---")
                 for i, _ in enumerate(tmp):
                     if tmp[i] != tmp2[i]:
-                        print(f'{tmp[i]} vs {tmp2[i]}')
-            
-        
+                        print(f"{tmp[i]} vs {tmp2[i]}")
+
         return self._compare_sequential(result, expected)
 
     @TestClass.is_a_test
@@ -270,7 +295,7 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         return self._compare_sequential(result, expected)
 
     @TestClass.is_a_test
@@ -294,7 +319,9 @@ class TestCSVUtils(TestClass):
             enable_autos=False,
             fight_start_time=0,
         )
-        rb, _ = CSVUtils.populate_rotation_from_csv(rb, self.__test_csv_filename_nonexistent_skill)
+        rb, _ = CSVUtils.populate_rotation_from_csv(
+            rb, self.__test_csv_filename_nonexistent_skill
+        )
 
         expected = (
             (
@@ -328,7 +355,7 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         return self._compare_sequential(result, expected)
 
     @TestClass.is_a_test
@@ -349,10 +376,12 @@ class TestCSVUtils(TestClass):
             stats,
             self.__skill_library,
             ignore_trailing_dots=True,
-            enable_autos=True, #enable autos and check them
+            enable_autos=True,  # enable autos and check them
             fight_start_time=0,
         )
-        rb, _ = CSVUtils.populate_rotation_from_csv(rb, self.__test_csv_filename_downtime_windows)
+        rb, _ = CSVUtils.populate_rotation_from_csv(
+            rb, self.__test_csv_filename_downtime_windows
+        )
 
         expected = (
             (
@@ -431,9 +460,9 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         return self._compare_sequential(result, expected)
-    
+
     @TestClass.is_a_test
     def test_csv_reader_multitarget(self):
         stats = Stats(
@@ -455,7 +484,9 @@ class TestCSVUtils(TestClass):
             enable_autos=False,
             fight_start_time=0,
         )
-        rb, _ = CSVUtils.populate_rotation_from_csv(rb, self.__test_csv_filename_multitarget)
+        rb, _ = CSVUtils.populate_rotation_from_csv(
+            rb, self.__test_csv_filename_multitarget
+        )
 
         expected = (
             (
@@ -476,7 +507,7 @@ class TestCSVUtils(TestClass):
                 ),
                 SkillModifier(),
                 [True, True],
-                ("Boss1","Boss2","Boss3"),
+                ("Boss1", "Boss2", "Boss3"),
             ),
             (
                 SnapshotAndApplicationEvents.EventTimes(6000, None),
@@ -486,15 +517,15 @@ class TestCSVUtils(TestClass):
                 ),
                 SkillModifier(),
                 [True, True],
-                ("Boss1","Boss2"),
+                ("Boss1", "Boss2"),
             ),
         )
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:6] for x in rb.get_skill_timing().get_q()]
-        
+
         return self._compare_sequential(result, expected)
-    
+
     @TestClass.is_a_test
     def test_csv_read_headers_stats(self):
         rb = RotationBuilder(
@@ -538,7 +569,7 @@ class TestCSVUtils(TestClass):
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
         test_passed1, err_msg1 = self._compare_sequential(result, expected)
-        
+
         expected_stats = Stats(
             wd=126,
             weapon_delay=4.5,
@@ -551,16 +582,16 @@ class TestCSVUtils(TestClass):
             job_class="test_job2",
             version="test",
         )
-        
+
         actual_stats = rb.get_stats()
         test_passed2 = True
-        err_msg2=""
+        err_msg2 = ""
         if expected_stats != actual_stats:
             test_passed2 = False
             err_msg2 = "Stats did not match"
-        
+
         return test_passed1 and test_passed2, ",".join([err_msg1, err_msg2])
-    
+
     @TestClass.is_a_test
     def test_csv_read_headers_enable_autos(self):
         stats = Stats(
@@ -582,7 +613,9 @@ class TestCSVUtils(TestClass):
             enable_autos=False,
             fight_start_time=0,
         )
-        rb, _ = CSVUtils.populate_rotation_from_csv(rb, self.__test_csv_filename_enable_autos)
+        rb, _ = CSVUtils.populate_rotation_from_csv(
+            rb, self.__test_csv_filename_enable_autos
+        )
 
         expected = (
             (
@@ -643,9 +676,9 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
+
         return self._compare_sequential(result, expected)
-    
+
     @TestClass.is_a_test
     def test_csv_lb(self):
         stats = Stats(
@@ -692,5 +725,352 @@ class TestCSVUtils(TestClass):
 
         result = rb.get_skill_timing().get_q()
         result = [x[1:5] for x in rb.get_skill_timing().get_q()]
-        
-        return self._compare_sequential(result, expected)
\ No newline at end of file
+
+        return self._compare_sequential(result, expected)
+
+    @TestClass.is_a_test
+    def test_csv_read_bulk1(self):
+        rb = RotationBuilder(
+            None,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            enable_autos=False,
+            fight_start_time=0,
+        )
+        result_rbs, _ = CSVUtils.get_bulk_rotations_from_csv(
+            {"player1": copy.deepcopy(rb), "player2": copy.deepcopy(rb)},
+            {
+                "player1": self.__test_bulk_filename1,
+                "player2": self.__test_bulk_filename2,
+            },
+        )
+
+        expected = {
+            "player1": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job",
+                    ),
+                    SkillModifier(),
+                ),
+                # buff distributed correctly to player 1
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+            "player2": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job2"),
+                    SkillModifier(),
+                ),
+            ),
+        }
+        return self.__do_rb_compare(result_rbs, expected)
+
+    @TestClass.is_a_test
+    def test_csv_read_bulk_with_targetted_buff(self):
+        rb = RotationBuilder(
+            None,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            enable_autos=False,
+            fight_start_time=0,
+        )
+        result_rbs, _ = CSVUtils.get_bulk_rotations_from_csv(
+            {
+                "player1": copy.deepcopy(rb),
+                "player2": copy.deepcopy(rb),
+                "player3": copy.deepcopy(rb),
+            },
+            {
+                "player1": self.__test_bulk_filename1,
+                "player2": self.__test_bulk_filename2,
+                "player3": self.__test_bulk_filename3,
+            },
+        )
+
+        expected = {
+            "player1": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(2000, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+            "player2": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job2"),
+                    SkillModifier(),
+                ),
+            ),
+            "player3": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(2000, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job2"),
+                    SkillModifier(),
+                ),
+            ),
+        }
+
+        return self.__do_rb_compare(result_rbs, expected)
+
+    @TestClass.is_a_test
+    def test_csv_read_bulk_with_targetted_buff_multi(self):
+        rb = RotationBuilder(
+            None,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            enable_autos=False,
+            fight_start_time=0,
+        )
+        result_rbs, _ = CSVUtils.get_bulk_rotations_from_csv(
+            rb,
+            {
+                "player1": self.__test_bulk_filename1,
+                "player2": self.__test_bulk_filename1,
+                "player3": self.__test_bulk_filename5,
+                "player4": self.__test_bulk_filename1,
+            },
+        )
+
+        expected = {
+            "player1": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+            "player2": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+            "player3": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job2"),
+                    SkillModifier(),
+                ),
+            ),
+            "player4": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+        }
+        return self.__do_rb_compare(result_rbs, expected)
+
+    @TestClass.is_a_test
+    def test_csv_read_bulk_overriding_condition(self):
+        rb = RotationBuilder(
+            None,
+            self.__skill_library,
+            ignore_trailing_dots=True,
+            enable_autos=False,
+            fight_start_time=0,
+        )
+        result_rbs, _ = CSVUtils.get_bulk_rotations_from_csv(
+            {"player1": copy.deepcopy(rb), "player2": copy.deepcopy(rb)},
+            {
+                "player1": self.__test_bulk_filename1,
+                "player2": self.__test_bulk_filename4,
+            },
+        )
+
+        expected = {
+            "player1": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job",
+                    ),
+                    SkillModifier(),
+                ),
+                # buff distributed correctly to player 1
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(with_condition="blahblah"),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job"),
+                    SkillModifier(),
+                ),
+            ),
+            "player2": (
+                (
+                    SnapshotAndApplicationEvents.EventTimes(0, None),
+                    self.__skill_library.get_skill(
+                        "test_instant_gcd",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(1200, None),
+                    self.__skill_library.get_skill(
+                        "test_party_buff",
+                        "test_job2",
+                    ),
+                    SkillModifier(),
+                ),
+                (
+                    SnapshotAndApplicationEvents.EventTimes(3000, None),
+                    self.__skill_library.get_skill("test_instant_gcd", "test_job2"),
+                    SkillModifier(),
+                ),
+            ),
+        }
+
+        return self.__do_rb_compare(result_rbs, expected)
\ No newline at end of file
