@@ -6,7 +6,7 @@ from ama_xiv_combat_sim.simulator.testing.create_test_skill_library import (
     create_test_skill_library,
 )
 from ama_xiv_combat_sim.simulator.testing.test_class import TestClass
-from ama_xiv_combat_sim.simulator.trackers.status_effects import StatusEffects
+from ama_xiv_combat_sim.simulator.trackers.offensive_status_effects import OffensiveStatusEffects
 
 
 class TestDamageSimulator(TestClass):
@@ -44,7 +44,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job2"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -52,7 +52,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd_trait_override", "test_job2"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -72,7 +72,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_guaranteed_crit_dot", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -80,7 +80,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_guaranteed_dh_dot", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -90,7 +90,7 @@ class TestDamageSimulator(TestClass):
                     "test_guaranteed_crit_dh_dot", "test_job"
                 ),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -113,7 +113,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -123,7 +123,7 @@ class TestDamageSimulator(TestClass):
                     "test_guaranteed_no_crit_dh", "test_job"
                 ),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -147,8 +147,8 @@ class TestDamageSimulator(TestClass):
                 self.__skill_library.get_skill("test_instant_gcd", "test_job"),
                 SkillModifier(),
                 (
-                    StatusEffects(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                    StatusEffects(),
+                    OffensiveStatusEffects(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
+                    OffensiveStatusEffects(),
                 ),
                 1,
                 "t1",
@@ -158,8 +158,8 @@ class TestDamageSimulator(TestClass):
                 self.__skill_library.get_skill("test_instant_gcd", "test_job"),
                 SkillModifier(),
                 (
-                    StatusEffects(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                    StatusEffects(),
+                    OffensiveStatusEffects(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
+                    OffensiveStatusEffects(),
                 ),
                 2,
                 "t1",
@@ -183,7 +183,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_guaranteed_crit", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -191,7 +191,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_guaranteed_dh", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -199,7 +199,7 @@ class TestDamageSimulator(TestClass):
                 2000,
                 self.__skill_library.get_skill("test_guaranteed_crit_dh", "test_job"),
                 SkillModifier(),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -222,7 +222,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -230,7 +230,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -241,7 +241,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -264,7 +264,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -272,7 +272,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -283,7 +283,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -307,7 +307,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -315,7 +315,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -326,7 +326,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -350,7 +350,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -358,7 +358,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -369,7 +369,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -394,7 +394,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -402,7 +402,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -413,7 +413,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
@@ -436,7 +436,7 @@ class TestDamageSimulator(TestClass):
                 0,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_crit=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 1,
                 "t1",
             ),
@@ -444,7 +444,7 @@ class TestDamageSimulator(TestClass):
                 1000,
                 self.__skill_library.get_skill("test_gcd", "test_job"),
                 SkillModifier(guaranteed_dh=ForcedCritOrDH.FORCE_YES),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 2,
                 "t1",
             ),
@@ -455,7 +455,7 @@ class TestDamageSimulator(TestClass):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                (StatusEffects(), StatusEffects()),
+                (OffensiveStatusEffects(), OffensiveStatusEffects()),
                 3,
                 "t1",
             ),
